# hanzo-studio_frontend pypi package

This is the pypi package structure for the hanzo-studio frontend.

During build process, the compiled assets are copied into the `${PROJECT_ROOT}/hanzo-studio_frontend_package/hanzo-studio_frontend_package/static` directory.

The package can be installed with the following command:

```bash
pip install hanzo-studio-frontend-package
```

Ref: <https://pypi.org/project/hanzo-studio-frontend-package/>
